From e5adc376d2eb6a5ae676340d0ca13183ef02b42e Mon Sep 17 00:00:00 2001
Message-Id: <e5adc376d2eb6a5ae676340d0ca13183ef02b42e.1335891157.git.rminnich@gmail.com>
In-Reply-To: <cover.1335891157.git.rminnich@gmail.com>
References: <cover.1335891157.git.rminnich@gmail.com>
From: Vadim Bendebury <vbendeb@chromium.org>
Date: Mon, 23 May 2011 13:39:40 -0700
Subject: [PATCH 01/15] Fix seabios build problems.
To: rminnich@gmail.com

When compiling seabios under ebuild control some compilation
warnings and util script problems are reported.

This CL fixes the problems. Emerging the package shows the
test-gcc.sh is ran multiple times, this does not seem to be a
make concurrency problem, as it is ran twice even when -j 1 make
option is specified. chromium-os:15658 is opened to track this
issue.

BUG=chrome-os-partner:6108
TEST=emerge-lumpy chromeos-seabios

Change-Id: Ideb545c3825d46eb7302815b81d6f19a7068c5a3
Signed-off-by: Vadim Bendebury <vbendeb@chromium.org>
Signed-off-by: Vincent Palatin <vpalatin@chromium.org>
---
 tools/test-gcc.sh |   29 +++++++++++++++--------------
 1 file changed, 15 insertions(+), 14 deletions(-)

diff --git a/tools/test-gcc.sh b/tools/test-gcc.sh
index 05bae29..ed62519 100755
--- a/tools/test-gcc.sh
+++ b/tools/test-gcc.sh
@@ -9,6 +9,11 @@ TMPFILE2=out/tmp_testcompile2.c
 TMPFILE2o=out/tmp_testcompile2.o
 TMPFILE3o=out/tmp_testcompile3.o
 
+this_prog=$(basename $0)
+report_error() {
+  (1>&2 echo "** $this_prog: $*" )
+}
+
 # Test if ld's alignment handling is correct.  This is a known problem
 # with the linker that ships with Ubuntu 11.04.
 cat - > $TMPFILE1 <<EOF
@@ -30,13 +35,13 @@ EOF
 $CC -O -g -c $TMPFILE1 -o $TMPFILE1o > /dev/null 2>&1
 $LD -T $TMPFILE1_ld $TMPFILE1o -o $TMPFILE2o > /dev/null 2>&1
 if [ $? -ne 0 ]; then
-    echo "The version of LD on this system does not properly handle" >&2
-    echo "alignments.  As a result, this project can not be built." >&2
-    echo "" >&2
-    echo "The problem may be the result of this LD bug report:" >&2
-    echo " http://sourceware.org/bugzilla/show_bug.cgi?id=12726" >&2
-    echo "" >&2
-    echo "Please update to a working version of binutils and retry." >&2
+    report_error "The version of LD on this system does not properly handle"
+    report_error "alignments.  As a result, this project can not be built."
+    report_error ""
+    report_error "The problem may be the result of this LD bug report:"
+    report_error " http://sourceware.org/bugzilla/show_bug.cgi?id=12726"
+    report_error "" >&2
+    report_error "Please update to a working version of binutils and retry."
     echo -1
     exit 0
 fi
@@ -45,7 +50,7 @@ fi
 # support the whole-program optimization - detect that.
 $CC -fwhole-program -S -o /dev/null -xc /dev/null > /dev/null 2>&1
 if [ $? -ne 0 ]; then
-    echo "  Working around no -fwhole-program" >&2
+    report_error "  Working around no -fwhole-program"
     echo 2
     exit 0
 fi
@@ -69,9 +74,7 @@ EOF
 $CC -Os -c -fwhole-program $TMPFILE2 -o $TMPFILE2o > /dev/null 2>&1
 $CC -nostdlib -Os $TMPFILE1o $TMPFILE2o -o $TMPFILE3o > /dev/null 2>&1
 if [ $? -ne 0 ]; then
-    echo "  Working around non-functional -fwhole-program" >&2
-    echo 2
-    exit 0
+    report_error "  Working around non-functional -fwhole-program"
 fi
 
 # Test if "-combine" works.  On Ubuntu 8.04 the compiler doesn't work
@@ -104,9 +107,7 @@ $CC -O -g -fwhole-program -combine -c $TMPFILE1 $TMPFILE2 -o $TMPFILE1o > /dev/n
 if [ $? -eq 0 ]; then
     echo 0
 else
-    echo "  Working around non-functional -combine" >&2
-    echo 1
-fi
+    report_error "  Working around non-functional -combine"
 
 # Also, on several compilers, -combine fails if code is emitted with a
 # reference to an extern variable that is later found to be externally
-- 
1.7.10
